MessageService class

Constructors

MessageService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForMessages(String username) → Future<void>
getUsername() → Future<String?>
initializeService() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onIosBackground(ServiceInstance service) → Future<bool>
readMessages(String username, String msgId) → Future<void>
requestIOSNotificationPermissions() → Future<void>
requestNotificationPermission() → Future<void>
stopNotification() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

saveUsername(String username) → Future<void>